# finance-quote-python

Finance::Quote implemented in Python

The idea for this project is to implement the [Finance::Quote](https://github.com/finance-quote/finance-quote) in Python and make it available to other Python code as a library.

## Development

Register the module with `pip install -e .` from the root directory.

## Installation

Install required dependencies as needed. The installation is not enforced because different download modules require different libraries.
